---
title: agents
---

# `marvin.agents`

## Submodules
- [`actor`](marvin-agents-actor)
- [`agent`](marvin-agents-agent)
- [`names`](marvin-agents-names)
- [`team`](marvin-agents-team)

---

**Parent Module:** [`marvin`](marvin)
